# Learning Resources

## Machine Learning 

### Q-Learning 
- [Original paper](https://www.academia.edu/download/50360235/Learning_from_delayed_rewards_20161116-28282-v2pwvq.pdf)
- [Wikipedia page](https://en.wikipedia.org/wiki/Q-learning)
- [Guide on using Q-Learning in checkers](https://blog.paperspace.com/building-a-checkers-gaming-agent-using-neural-networks-and-reinforcement-learning/)

### Minimax and Alpha-Beta pruning 
- [Final project by another student](https://www.cs.huji.ac.il/w~ai/projects/old/English-Draughts.pdf)
